==> 0.10.1.tar.gz: lib/bloc/rewards_module/pages/cas_insentive_approver.dart <==


import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:shared_preferences/shared_preferences.dart';

import '../../../utils/colors.dart';
import '../../../utils/custom_app_bar.dart';
import '../../../utils/custom_tab_maker.dart';
import '../../../utils/hexColors.dart';
import '../../../utils/localization.dart';
import '../../../utils/locator.dart';
import '../../../utils/text_styling.dart';
import '../../cubits/cubit_main.dart';
import 'add_cash_approvers.dart';
import 'add_team_member.dart';
import 'member_page.dart';


// ignore: must_be_immutable
class CashIncentiveApprove extends StatefulWidget {



  CashIncentiveApproveState createState() => CashIncentiveApproveState();
}

class CashIncentiveApproveState extends State<CashIncentiveApprove>
    with SingleTickerProviderStateMixin {
  List<CustomTabMaker>? list = [];
  late TabController _tabController;
  late TextStyleElements styleElements;
  List<PopupMenuItem>? menuItems;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();
  String? ownerType;
  int? ownerId;

  int _currentPosition = 0;
  String? pageTitle;
  late Null Function() callback;
  String? imageUrl;
  List<PopupMenuItem> menuList = [];
  List<Widget> invitePartnerList = [];

  List<Widget> invitePartnerEmployeeList = [];
  String? type;

  bool isMultiSelectEnabled = false;

  @override
  void initState() {
    super.initState();


  }




  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return SafeArea(
      child: Scaffold(
        resizeToAvoidBottomInset: true,
        backgroundColor: HexColor(AppColors.appColorBackground),

        appBar: appAppBar().getCustomAppBar(context,
            appBarTitle: AppLocalizationsRewards.of(context)!.translate('cash_approve'),
            actions: [  InkWell(
              onTap: () {

                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:     AddCashApprovePage(),
                ),));




              },
              child: Padding(
                padding: const EdgeInsets.only(left: 12, right: 12.0),
                child: Icon(Icons.add_circle,
                    color: HexColor(AppColors.blueApp)),
              ),
            ),],
            onBackButtonPress: () {
              Navigator.pop(context);
            }),




        // appAppBar().getCustomAppBar(context,
        //     appBarTitle: pageTitle+"'s "+AppLocalizations.of(context).translate('network'),
        //     onBackButtonPress: () {
        //       Navigator.pop(context);
        //     }),
        body:MemberPage(
          callBack: () {

          },
          multiSelectionEnabled: (val) {
            setState(() {
              isMultiSelectEnabled = val;
            });
          },
          key: null,
          type: "contacts", ownerId: 9, isUserAdmin: true,
        ),
      ),
    );
  }


}

==> 0.11.1.tar.gz: lib/bloc/rewards_module/pages/cas_insentive_approver.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:shared_preferences/shared_preferences.dart';

import '../../../utils/colors.dart';
import '../../../utils/custom_app_bar.dart';
import '../../../utils/custom_tab_maker.dart';
import '../../../utils/hexColors.dart';
import '../../../utils/localization.dart';
import '../../../utils/locator.dart';
import '../../../utils/text_styling.dart';
import '../../cubits/cubit_main.dart';
import 'add_cash_approvers.dart';
import 'add_team_member.dart';
import 'member_page.dart';

// ignore: must_be_immutable
class CashIncentiveApprove extends StatefulWidget {
  CashIncentiveApproveState createState() => CashIncentiveApproveState();
}

class CashIncentiveApproveState extends State<CashIncentiveApprove>
    with SingleTickerProviderStateMixin {
  List<CustomTabMaker>? list = [];
  late TabController _tabController;
  late TextStyleElements styleElements;
  List<PopupMenuItem>? menuItems;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();
  String? ownerType;
  int? ownerId;

  int _currentPosition = 0;
  String? pageTitle;
  late Null Function() callback;
  String? imageUrl;
  List<PopupMenuItem> menuList = [];
  List<Widget> invitePartnerList = [];

  List<Widget> invitePartnerEmployeeList = [];
  String? type;

  bool isMultiSelectEnabled = false;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return SafeArea(
      child: Scaffold(
        resizeToAvoidBottomInset: true,
        backgroundColor: HexColor(AppColors.appColorBackground),

        appBar: appAppBar().getCustomAppBar(context,
            appBarTitle:
                AppLocalizationsRewards.of(context)!.translate('cash_approve'),
            actions: [
              InkWell(
                onTap: () {
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (context) => BlocProvider(
                          create: (_) => CubitMain(),
                          child: AddCashApprovePage(),
                        ),
                      ));
                },
                child: Padding(
                  padding: const EdgeInsets.only(left: 12, right: 12.0),
                  child: Icon(Icons.add_circle,
                      color: HexColor(AppColors.blueApp)),
                ),
              ),
            ], onBackButtonPress: () {
          Navigator.pop(context);
        }),

        // appAppBar().getCustomAppBar(context,
        //     appBarTitle: pageTitle+"'s "+AppLocalizations.of(context).translate('network'),
        //     onBackButtonPress: () {
        //       Navigator.pop(context);
        //     }),
        body: MemberPage(
          callBack: () {},
          multiSelectionEnabled: (val) {
            setState(() {
              isMultiSelectEnabled = val;
            });
          },
          key: null,
          type: "contacts",
          ownerId: 9,
          isUserAdmin: true,
        ),
      ),
    );
  }
}
